BaseProfile
===========

.. contents::

For a documentation of the variables, please look at the documentation of :class:`ProfileInterface <pyhafas.profile.interfaces.ProfileInterface>`

.. automodule:: pyhafas.profile.base
   :members:
   :undoc-members:
   :show-inheritance:

Helper
------
format_products_filter
^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: pyhafas.profile.base.helper.format_products_filter
   :members:
   :undoc-members:
   :show-inheritance:

date_time
^^^^^^^^^^^^^^^
.. automodule:: pyhafas.profile.base.helper.date_time
   :members:
   :undoc-members:
   :show-inheritance:

parse_leg
^^^^^^^^^
.. automodule:: pyhafas.profile.base.helper.parse_leg
   :members:
   :undoc-members:
   :show-inheritance:

parse_lid
^^^^^^^^^
.. automodule:: pyhafas.profile.base.helper.parse_lid
   :members:
   :undoc-members:
   :show-inheritance:

request
^^^^^^^^^
.. automodule:: pyhafas.profile.base.helper.request
   :members:
   :undoc-members:
   :show-inheritance:

Mappings
--------

error_codes
^^^^^^^^^^^
.. automodule:: pyhafas.profile.base.mappings.error_codes
   :members:
   :undoc-members:
   :show-inheritance:

Requests
--------

journey
^^^^^^^
.. automodule:: pyhafas.profile.base.requests.journey
   :members:
   :undoc-members:
   :show-inheritance:

journeys
^^^^^^^^
.. automodule:: pyhafas.profile.base.requests.journeys
   :members:
   :undoc-members:
   :show-inheritance:

location
^^^^^^^^
.. automodule:: pyhafas.profile.base.requests.location
   :members:
   :undoc-members:
   :show-inheritance:

station_board
^^^^^^^^^^^^^
.. automodule:: pyhafas.profile.base.requests.station_board
   :members:
   :undoc-members:
   :show-inheritance:

trip
^^^^
.. automodule:: pyhafas.profile.base.requests.trip
   :members:
   :undoc-members:
   :show-inheritance:
